package ru.windcorp.turretlang.saveable;

/**
 * Interface that all classes willing to be saved must implement. The class must also provide a constructor with String[] argument.
 * <i>In case it is necessary to save a pre-existing class, e.g. Player, a new class should be made:</i><p>
 * <code>class SPlayer extends CraftPlayer implements TLSaveable {<br>
 *    <b>public SPlayer(String[] args)</b> {<br>
 *       //do stuff<br>
 *    }<br>
 *    <br>
 *    @Override<br>
 *    public String[] toTLString() {<br>
 *       //collect and return data<br>
 *    }<br>}</code>
 * */
public interface TLSaveable {
	
	/**
	 * Returns an array of Strings used to save this Object in Turret Language configurations.<p>
	 * Note that <b>all TLSaveables must have a public constructor TLSaveable(String[] args)</b>
	 * that will be invoked when initializing the object from a declaration, otherwise an {@link TLSaveableException} is thrown.
	 * None of the returned Strings may contain any new line characters (\n) nor asterisks (*).
	 * @return The String[] required to instantiate the object later.
	 * */
	public String[] toTLString();
}
