package ru.windcorp.turretlang.util;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * Utility class for file IO.
 * */
public final class FileIOUtil {

	private FileIOUtil() {}
	
	/**
	 * Returns the content of the specified file divided into lines.
	 * @return The List of all lines in the file.
	 * @param source The file to read.
	 * @throws IOException If any IO error occurs.
	 * @see FileIOUtil#content(File)
	 * */
	public static final List<String> lines(File source) throws IOException {
		assert source != null;
		
		BufferedReader br = new BufferedReader(new FileReader(source.getAbsoluteFile()));
		List<String> vars = new ArrayList<String>(); String s;
		while ((s = br.readLine()) != null) {
			vars.add(s);
		}
		br.close();
		
		return vars;
	}
	
	/**
	 * Returns the content of the specified file.
	 * @return The String representing all data of the file.
	 * @param source The file to read.
	 * @throws IOException If any IO error occurs.
	 * @see FileIOUtil#lines(File)
	 * */
	public static final String content(File source) throws IOException {
		StringBuilder sb = new StringBuilder();
		for (String l : lines(source)) {
			sb.append(l);
		}
		return sb.toString();
	}
	
	/**
	 * Writes data to the specified file. File must already exist.
	 * @param source The file to write to.
	 * @param content The data to write to the file.
	 * @throws IOException If any IO error occurs.
	 * */
	public static final void write(File source, String content) throws IOException {
		assert content != null && source != null;
		FileWriter fw = new FileWriter(source.getAbsoluteFile());
		BufferedWriter bw = new BufferedWriter(fw);
		bw.write(content);
		bw.close();
	}

}
